<?php
/* Copyright (C) 2002-2005 Rodolphe Quiedeville <rodolphe@quiedeville.org>
 * Copyright (C) 2004      Eric Seigne          <eric.seigne@ryxeo.com>
 * Copyright (C) 2004-2014 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2005-2012 Regis Houssin        <regis.houssin@capnetworks.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *		\file       htdocs/compta/facture/impayees.php
 *		\ingroup    facture
 *		\brief      Page to list and build liste of unpaid invoices
 */

require '../../main.inc.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/html.formfile.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/html.formother.class.php';
require_once DOL_DOCUMENT_ROOT.'/compta/facture/class/facture.class.php';
require_once DOL_DOCUMENT_ROOT . '/core/modules/facture/modules_facture.php';
require_once DOL_DOCUMENT_ROOT.'/compta/paiement/class/paiement.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/files.lib.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/pdf.lib.php';
require_once DOL_DOCUMENT_ROOT.'/product/class/product.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/company.lib.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/pdf.lib.php';
require_once DOL_DOCUMENT_ROOT . '/core/class/extrafields.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/discount.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/functions2.lib.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/invoice.lib.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/date.lib.php';
if (! empty($conf->commande->enabled)) require_once DOL_DOCUMENT_ROOT.'/commande/class/commande.class.php';
if (! empty($conf->projet->enabled))
{
	require_once DOL_DOCUMENT_ROOT.'/projet/class/project.class.php';
}

$langs->load("bills");

$id = (GETPOST('facid','int') ? GETPOST('facid','int') : GETPOST('id','int'));
$socid=GETPOST('socid','int');
$action = GETPOST('action','alpha');
$option = GETPOST('option');
$sall=trim(GETPOST('sall'));
$projectid=(GETPOST('projectid')?GETPOST('projectid','int'):0);

$id=(GETPOST('id','int')?GETPOST('id','int'):GETPOST('facid','int'));  // For backward compatibility
$ref=GETPOST('ref','alpha');
$socid=GETPOST('socid','int');
$action=GETPOST('action','alpha');
$confirm=GETPOST('confirm','alpha');
$lineid=GETPOST('lineid','int');
$userid=GETPOST('userid','int');
$search_ref=GETPOST('sf_ref')?GETPOST('sf_ref','alpha'):GETPOST('search_ref','alpha');
$search_societe=GETPOST('search_societe','alpha');
$search_montant_ht=GETPOST('search_montant_ht','alpha');
$search_montant_ttc=GETPOST('search_montant_ttc','alpha');
$origin=GETPOST('origin','alpha');
$originid=(GETPOST('originid','int')?GETPOST('originid','int'):GETPOST('origin_id','int')); // For backward compatibility
$day	= GETPOST('day','int');
$month	= GETPOST('month','int');
$year	= GETPOST('year','int');
$lastday	= GETPOST('lastday','int');
$lastmonth	= GETPOST('lastmonth','int');
$lastyear	= GETPOST('lastyear','int');
$filtre	= GETPOST('filtre');


// Security check
if ($user->societe_id) $socid=$user->societe_id;
$result = restrictedArea($user,'facture',$id,'');

$diroutputpdf=$conf->facture->dir_output . '/unpaid/temp';
if (! $user->rights->societe->client->voir || $socid) $diroutputpdf.='/private/'.$user->id;	// If user has no permission to see all, output dir is specific to user


/*
 * Action
 */

if ($action == "builddoc" && $user->rights->facture->lire && ! GETPOST('button_search'))
{
	if (is_array($_POST['toGenerate']))
	{
	    $arrayofinclusion=array();
	    foreach($_POST['toGenerate'] as $tmppdf) $arrayofinclusion[]=preg_quote($tmppdf.'.pdf','/');
		$factures = dol_dir_list($conf->facture->dir_output,'all',1,implode('|',$arrayofinclusion),'\.meta$|\.png','date',SORT_DESC);

		// liste les fichiers
                
		$files = array();
		$factures_bak = $factures ;
		foreach($_POST['toGenerate'] as $basename){
			/*
                        foreach($factures as $facture){
				if(strstr($facture["name"],$basename)){
					$files[] = $conf->facture->dir_output.'/'.$basename.'/'.$facture["name"];                                                                    
					
				}
			}
                        */
                        $object=new Facture($db);
                        $object->fetch($basename);
                        $combine[] = $object;
                        
                        
		}
                //exit();

        // Define output language (Here it is not used because we do only merging existing PDF)
        $outputlangs = $langs;
        $newlang='';
        if ($conf->global->MAIN_MULTILANGS && empty($newlang) && GETPOST('lang_id')) $newlang=GETPOST('lang_id');
        if ($conf->global->MAIN_MULTILANGS && empty($newlang)) $newlang=$object->client->default_lang;
        if (! empty($newlang))
        {
            $outputlangs = new Translate("",$conf);
            $outputlangs->setDefaultLang($newlang);
        }

        // Create empty PDF
        $pdf=pdf_getInstance();
        if (class_exists('TCPDF'))
        {
            $pdf->setPrintHeader(false);
            $pdf->setPrintFooter(false);
        }
        $pdf->SetFont(pdf_getPDFFont($outputlangs));

        if (! empty($conf->global->MAIN_DISABLE_PDF_COMPRESSION)) $pdf->SetCompression(false);

               
          
            
$pdf->SetCreator(PDF_CREATOR);


// set default header data
$pdf->SetHeaderData(PDF_HEADER_LOGO, PDF_HEADER_LOGO_WIDTH, PDF_HEADER_TITLE.' 006', PDF_HEADER_STRING);

// set header and footer fonts
$pdf->setHeaderFont(Array(PDF_FONT_NAME_MAIN, '', PDF_FONT_SIZE_MAIN));
$pdf->setFooterFont(Array(PDF_FONT_NAME_DATA, '', PDF_FONT_SIZE_DATA));

// set default monospaced font
$pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);

// set margins
$pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP+20, PDF_MARGIN_RIGHT);
$pdf->SetHeaderMargin(PDF_MARGIN_HEADER);
$pdf->SetFooterMargin(PDF_MARGIN_FOOTER);

// set auto page breaks
$pdf->SetAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);

// set image scale factor
$pdf->setImageScale(PDF_IMAGE_SCALE_RATIO);

// set some language-dependent strings (optional)
if (@file_exists(dirname(__FILE__).'/lang/eng.php')) {
    require_once(dirname(__FILE__).'/lang/eng.php');
    $pdf->setLanguageArray($l);
}

// ---------------------------------------------------------
  
  //to get the third party details
	$soc = new Societe($db);
	$soc->fetch($object->socid);
// set font
$pdf->SetFont('dejavusans', '', 10);

                
  $left_column="From:";   
  $right_column="To:";
  $nowda=dol_now();
  $datedd=dol_print_date(dol_now());
  $receivername=$soc->nom;
  $receiveradd=$soc->address;
  $receiverphone=$soc->phone;
  $receiveremail=$soc->email;
  $receivertown=$soc->town;
  $receivercode=$soc->code_client;
  $receiverclient=$soc->client;
  
  $html="";
  
  $html.=<<<EOF
     
    <br>
          <br>
          <br>
          
        
<table height="405" border="0" cellpadding="2" cellspacing="2" >
<thead>
 <tr >
   <td width="120" align="center" >Date</td>
    <td width="120" align="center">Ref.No</td>
    <td width="120" align="center">Opening Amount</td>
   <td width="120" align="center">Pending Amount</td>
    <td width="120" align="center">Due On</td>
   
          
 </tr>
</thead>


  
EOF;
          $sum = 0;
          asort($combine);
                  foreach($combine as $invoice)
		{
			
                $invoicenumber=$invoice->ref;
                $paiement = $invoice->getSommePaiement(); 
                $totalamount=price($invoice->total_ht);
                $pendingamount=$invoice->total_ht-$paiement;
                $pending=price($pendingamount);
                $sumingpending+=$pendingamount;
                $pendingtotal=price($sumingpending);
                $dateded=dol_print_date($invoice->date);
              
                $datedue=dol_print_date($invoice->date_lim_reglement);
                 // $overdate=date_diff($nowda,$datedue);
                 $sum+=$invoice->total_ht;
                 $total=price($sum);
                 
                $html.=<<<EOF
                 <tr>
                 <td width="120" align="center">$dateded</td>
                 <td width="120" align="center">$invoicenumber</td>
                 <td width="120" align="right">$totalamount</td>
                 <td width="120" align="right">$pending</td>
                 <td width="120" align="center">$datedue</td>
                 
   </tr>
EOF;

                }
                
                $html.=<<<EOF
 <tr>
                        <td width="120" align="center"></td>
                        <td width="120" align="center"></td>
                        <td width="120" align="right"> <br/>AED &nbsp;$total</td>
                        <td width="120" align="right"> <br/>AED&nbsp;$pendingtotal</td>
                        <td width="120" align="center"></td>
                       
                        
 </tr>
  
</table>
EOF;
// output the HTML content

                //Attach header
                
                //Attach footer
                
                $pagecount = 1;
                // add a page
                $pdf->AddPage();
                //Write header footer
$y = $pdf->getY();

// set color for background
$pdf->SetFillColor(230,230,230);

// set color for text
$pdf->SetTextColor(0, 0, 0);

//Pdf document name .
$pdf->writeHTMLCell(0, 0, 89,$y+30, 'Customer Statements', 0,0, 0, true, 'L', true);

$pdf->SetFillColor(255, 255, 255);
$pdf->writeHTMLCell(185, 90, '', $y+99, '', 1, 1, 1, true, 'L', true);
//$pdf->writeHTMLCell(50, 10, 75, $y+135, , 1, 1, 1, true, 'L', true);
$pdf->writeHTMLCell(185, 4, '', $y+95, '', 1, 1, 1, true, 'L', true);
//$pdf->writeHTMLCell(0.1, 90, 125, $y+55, '', 1, 1, 1, true, 'L', true);
// set color for text
$pdf->SetTextColor(0, 0, 0);
$pdf->writeHTMLCell(75, 30, 164,$y+30, 'Dated'.':'.$datedd, 0, 0, 0, true, 'L', true);


// write the first column
$pdf->writeHTMLCell(75, 45, '', $y+40, $left_column, 1, 0, 1, true, 'L', true);
$pdf->writeHTMLCell(75, 45, '', $y+44, '<font size="10">Al Najah Tyres Shop</font>', 0, 0, 0, true, 'L', true);
//$pdf->writeHTMLCell(75, 45, '', $y+4, $receivercode, 0, 0, 0, true, 'L', true);
$pdf->writeHTMLCell(75, 45, '', $y+48, '<font size="8">Mussafah M 14</font>', 0, 0, 0, true, 'L', true);
$pdf->writeHTMLCell(75, 45, '', $y+52, '<font size="8">4484 Abu Dhabi - U.A.E</font>', 0, 0, 0, true, 'L', true);
$pdf->writeHTMLCell(75, 45, '', $y+56, '<font size="8">Phone: +97125544115</font>', 0, 0, 0, true, 'L', true);
$pdf->writeHTMLCell(75, 45, '', $y+60, '<font size="8">Fax: +97125544240</font>', 0, 0, 0, true, 'L', true);
$pdf->writeHTMLCell(75, 45, '', $y+64, '<font size="8">Email: info@alnajahtyres.com</font>', 0, 0, 0, true, 'L', true);
$pdf->writeHTMLCell(75, 45, '', $y+68, '<font size="8">Web: alnajahtyres.com</font>', 0, 0, 0, true, 'L', true);
$pdf->writeHTMLCell(75, 45, '', $y+30, 'No'.':'.$nowda, 0, 0, 0, true, 'L', true);
// write the second column
$pdf->writeHTMLCell(75, 45, 125,$y+40, $right_column, 1, 1, 1, true, 'L', true);
$pdf->writeHTMLCell(75, 30, 125, $y+44, '<font size="10">'.$receivername.'</font>', 0, 0, 0, true, 'L', true);
$pdf->writeHTMLCell(75, 30, 169, $y+44, '<font size="8">'.$receivercode.'</font>', 0, 0, 0, true, 'L', true);
$pdf->writeHTMLCell(75, 30, 125, $y+48, '<font size="8">'.$receiveradd.'</font>', 0, 0, 0, true, 'L', true);
$pdf->writeHTMLCell(75, 30, 125, $y+52,'<font size="8">'. $receivertown.'</font>', 0, 0, 0, true, 'L', true);
$pdf->writeHTMLCell(75, 30, 125, $y+56, '<font size="8">'.$receiverphone.'</font>', 0, 0, 0, true, 'L', true);
$pdf->writeHTMLCell(75, 30, 125, $y+60, '<font size="8">'.$receiveremail.'</font>', 0, 0, 0, true, 'L', true);


$pdf->SetTextColor(0, 0, 0);
$pdf->SetFillColor(0,0,0);
$pdf->writeHTMLCell(0, 0, 69,$y+89, 'Account statement between '.$day.'.'.$month.'.'.$year.'&nbsp;&nbsp;and&nbsp;&nbsp;'.$lastday.'.'.$lastmonth.'.'.$lastyear, 0,0, 0, true, 'L', true);


$pdf->writeHTML($html, true, false, false, false, 'J ');
$pdf->SetTextColor(0, 0, 0);
$pdf->writeHTMLCell(75, 30, '',$y+190, '<font size="8">Currency In United Arab Emirates Dirham</font>', 0, 0, 0, true, 'L', true);
$pdf->writeHTMLCell(75, 30, 140,$y+190, 'Authorised Signature', 0, 0, 0, true, 'L', true);

               // $this->_pagefoot($pdf,$object,$outputlangs);
				//if (method_exists($pdf,'AliasNbPages')) $pdf->AliasNbPages();

				//$pdf->Close();
                $pdf->lastPage();
                
		// Create output dir if not exists
		dol_mkdir($diroutputpdf);

		// Save merged file
		$filename=strtolower(dol_sanitizeFileName($langs->transnoentities("Statements")));
		if ($option=='late') $filename.='_'.strtolower(dol_sanitizeFileName($langs->transnoentities("Late")));
		if ($pagecount)
		{
                    
                 
			$now=dol_now();
			$file=$diroutputpdf.'/'.$filename.'_'.$now.'.pdf';
                 	$pdf->Output($file,'F'); 
			if (! empty($conf->global->MAIN_UMASK))
			@chmod($file, octdec($conf->global->MAIN_UMASK));
                        
                                                
		}
		else
		{
			$mesg='<div class="error">'.$langs->trans('NoPDFAvailableForChecked').'</div>';
		}
	}
	else
	{
		$mesg='<div class="error">'.$langs->trans('InvoiceNotChecked').'</div>' ;
	}        
        
        
}//Generating invoice merge

// Remove file
if ($action == 'remove_file')
{
	require_once DOL_DOCUMENT_ROOT.'/core/lib/files.lib.php';

	$langs->load("other");
	$upload_dir = $diroutputpdf;
	$file = $upload_dir . '/' . GETPOST('file');
	$ret=dol_delete_file($file,0,0,0,'');
	if ($ret) setEventMessage($langs->trans("FileWasRemoved", GETPOST('urlfile')));
	else setEventMessage($langs->trans("ErrorFailToDeleteFile", GETPOST('urlfile')), 'errors');
	$action='';
}



/*
 * View
 */
$form = new Form($db);
$formfile = new FormFile($db);
$formother = new FormOther($db);

$title=$langs->trans("BillsCustomersUnpaid");
if ($option=='late') $title=$langs->trans("BillsCustomersUnpaid");

llxHeader('',$title);

?>
<script type="text/javascript">
$(document).ready(function() {
	$("#checkall").click(function() {
		$(".checkformerge").attr('checked', true);
	});
	$("#checknone").click(function() {
		$(".checkformerge").attr('checked', false);
	});
});
</script>
<?php

$now=dol_now();
$sall=trim(GETPOST('sall'));
$search_ref = GETPOST("search_ref");
$search_societe = GETPOST("search_societe");
$search_montant_ht = GETPOST("search_montant_ht");
$search_montant_ttc = GETPOST("search_montant_ttc");
$late = GETPOST("late");

$sortfield = GETPOST("sortfield",'alpha');
$sortorder = GETPOST("sortorder",'alpha');
$page = GETPOST("page",'int');
if ($page == -1) { $page = 0; }
$offset = $conf->liste_limit * $page;
$pageprev = $page - 1;
$pagenext = $page + 1;
if (! $sortfield) $sortfield="f.date_lim_reglement";
if (! $sortorder) $sortorder="ASC";

$limit = $conf->liste_limit;

$sql = "SELECT s.nom, s.rowid as socid";
$sql.= ", f.rowid as facid, f.facnumber, f.increment, f.total as total_ht, f.tva as total_tva, f.total_ttc, f.localtax1, f.localtax2, f.revenuestamp";
$sql.= ", f.datef as df, f.date_lim_reglement as datelimite";
$sql.= ", f.paye as paye, f.fk_statut, f.type";
$sql.= ", sum(pf.amount) as am";
if (! $user->rights->societe->client->voir && ! $socid) $sql .= ", sc.fk_soc, sc.fk_user ";
$sql.= " FROM ".MAIN_DB_PREFIX."societe as s";
if (! $user->rights->societe->client->voir && ! $socid) $sql .= ", ".MAIN_DB_PREFIX."societe_commerciaux as sc";
$sql.= ",".MAIN_DB_PREFIX."facture as f";
$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."paiement_facture as pf ON f.rowid=pf.fk_facture ";
$sql.= " WHERE f.fk_soc = s.rowid";
$sql.= " AND f.entity = ".$conf->entity;
$sql.= " AND f.type IN (0,1,3) AND f.fk_statut = 1";
$sql.= " AND f.paye = 0";
if ($option == 'late') $sql.=" AND f.date_lim_reglement < '".$db->idate(dol_now() - $conf->facture->client->warning_delay)."'";
if (! $user->rights->societe->client->voir && ! $socid) $sql .= " AND s.rowid = sc.fk_soc AND sc.fk_user = " .$user->id;
if (! empty($socid)) $sql .= " AND s.rowid = ".$socid;
if ($month > 0)
{
    if ($year > 0 && empty($day))
    $sql.= " AND f.datef BETWEEN '".$db->idate(dol_get_first_day($year,$month,false))."' AND '".$db->idate(dol_get_last_day($lastyear,$lastmonth,false))."'";
    else if ($year > 0 && ! empty($day))
    $sql.= " AND f.datef BETWEEN '".$db->idate(dol_mktime(0, 0, 0, $month, $day, $year))."' AND '".$db->idate(dol_mktime(23, 59, 59, $lastmonth, $lastday, $lastyear))."'";
    else
    $sql.= " AND date_format(f.datef, '%m') = '".$month."'";
}
else if ($year > 0)
{
    $sql.= " AND f.datef BETWEEN '".$db->idate(dol_get_first_day($year,1,false))."' AND '".$db->idate(dol_get_last_day($lastyear,12,false))."'";
}
if ($filtre)
{
    $aFilter = explode(',', $filtre);
    foreach ($aFilter as $filter)
    {
        $filt = explode(':', $filter);
        $sql .= ' AND ' . trim($filt[0]) . ' = ' . trim($filt[1]);
    }
}

if ($search_ref)         $sql .= " AND f.facnumber LIKE '%".$db->escape($search_ref)."%'";
if ($search_societe)     $sql .= " AND s.nom LIKE '%".$db->escape($search_societe)."%'";
if ($search_montant_ht)  $sql .= " AND f.total = '".$db->escape($search_montant_ht)."'";
if ($search_montant_ttc) $sql .= " AND f.total_ttc = '".$db->escape($search_montant_ttc)."'";
if (GETPOST('sf_ref'))   $sql .= " AND f.facnumber LIKE '%".$db->escape(GETPOST('sf_ref'))."%'";
$sql.= " GROUP BY s.nom, s.rowid, f.rowid, f.facnumber, f.increment, f.total, f.tva, f.total_ttc, f.localtax1, f.localtax2, f.revenuestamp, f.datef, f.date_lim_reglement, f.paye, f.fk_statut, f.type ";
if (! $user->rights->societe->client->voir && ! $socid) $sql .= ", sc.fk_soc, sc.fk_user ";
$sql.= " ORDER BY ";
$listfield=explode(',',$sortfield);
foreach ($listfield as $key => $value) $sql.=$listfield[$key]." ".$sortorder.",";
$sql.= " f.facnumber DESC";

//$sql .= $db->plimit($limit+1,$offset);

$resql = $db->query($sql);
if ($resql)
{
	$num = $db->num_rows($resql);

	if (! empty($socid))
	{
		$soc = new Societe($db);
		$soc->fetch($socid);
	}

	$param="";
	$param.=(! empty($socid)?"&amp;socid=".$socid:"");
	$param.=(! empty($option)?"&amp;option=".$option:"");
        
	if ($day)              	$param.='&day='.$day;
	if ($month)            	$param.='&month='.$month;
    if ($year)          	$param.='&year=' .$year;
	if ($lastday)       	$param.='&lastday='.$lastday;
	if ($lastmonth)     	$param.='&lastmonth='.$lastmonth;
	if ($lastyear)      	$param.='&lastyear=' .$lastyear;
	if ($search_ref)         $param.='&amp;search_ref='.urlencode($search_ref);
	if ($search_societe)     $param.='&amp;search_societe='.urlencode($search_societe);
	if ($search_montant_ht)  $param.='&amp;search_montant_ht='.urlencode($search_montant_ht);
	if ($search_montant_ttc) $param.='&amp;search_montant_ttc='.urlencode($search_montant_ttc);
	if ($late)               $param.='&amp;late='.urlencode($late);

	$urlsource=$_SERVER['PHP_SELF'].'?sortfield='.$sortfield.'&sortorder='.$sortorder;
	$urlsource.=str_replace('&amp;','&',$param);

	$titre=(! empty($socid)?$langs->trans("BillsCustomersUnpaidForCompany",$soc->nom):$langs->trans("Customer Statement"));
	if ($option == 'late') $titre.=' ('.$langs->trans("Late").')';
	else $titre.=' ('.$langs->trans("All").')';

	$link='';
	if (empty($option)) $link='<a href="../facture/receipt.php">'.$langs->trans("Show Receipt(All)").'</a>';
	elseif ($option == 'late') $link='<a href="'.$_SERVER["PHP_SELF"].'">'.$langs->trans("ShowUnpaidAll").'</a>';
	print_fiche_titre($titre,$link);
	//print_barre_liste($titre,$page,$_SERVER["PHP_SELF"],$param,$sortfield,$sortorder,'',0);	// We don't want pagination on this page

	dol_htmloutput_mesg($mesg);

	print '<form id="form_generate_pdf" method="POST" action="'.$_SERVER["PHP_SELF"].'?sortfield='. $sortfield .'&sortorder='. $sortorder .'">';
	print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
	if ($late) print '<input type="hidden" name="late" value="'.dol_escape_htmltag($late).'">';

	$i = 0;
	print '<table class="liste" width="100%">';
	print '<tr class="liste_titre">';
	print_liste_field_titre($langs->trans("Ref"),$_SERVER["PHP_SELF"],"f.facnumber","",$param,"",$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("Date"),$_SERVER["PHP_SELF"],"f.datef","",$param,'align="center"',$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("DateDue"),$_SERVER["PHP_SELF"],"f.date_lim_reglement","",$param,'align="center"',$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("Company"),$_SERVER["PHP_SELF"],"s.nom","",$param,"",$sortfield,$sortorder);
	print_liste_field_titre($langs->trans(" Total Amount"),$_SERVER["PHP_SELF"],"f.total","",$param,'align="right"',$sortfield,$sortorder);
	//print_liste_field_titre($langs->trans("Taxes"),$_SERVER["PHP_SELF"],"f.tva","",$param,'align="right"',$sortfield,$sortorder);
	//print_liste_field_titre($langs->trans("AmountTTC"),$_SERVER["PHP_SELF"],"f.total_ttc","",$param,'align="right"',$sortfield,$sortorder);
	//print_liste_field_titre($langs->trans("Received"),$_SERVER["PHP_SELF"],"am","",$param,'align="right"',$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("Rest"),$_SERVER["PHP_SELF"],"am","",$param,'align="right"',$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("Status"),$_SERVER["PHP_SELF"],"fk_statut,paye,am","",$param,'align="right"',$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("Merge"),$_SERVER["PHP_SELF"],"","",$param,'align="center"',$sortfield,$sortorder);
	print "</tr>\n";

	// Lignes des champs de filtre
	print '<tr class="liste_titre">';
	// Ref
	print '<td class="liste_titre">';
	print '<input class="flat" size="10" type="text" name="search_ref" value="'.$search_ref.'"></td>';
	 print '<td class="liste_titre"><input class="flat" type="text" size="1" maxlength="2" name="day" value="'.$day.'">';
         print '<input class="flat" type="text" size="1" maxlength="2" name="month" value="'.$month.'">';
         $formother->select_year($year?$year:-1,'year',1, 20, 5);
         print '</td>';
         print '<td class="liste_titre"><input class="flat" type="text" size="1" maxlength="2" name="lastday" value="'.$lastday.'">';
         print '<input class="flat" type="text" size="1" maxlength="2" name="lastmonth" value="'.$lastmonth.'">';
         $formother->select_year($lastyear?$lastyear:-1,'lastyear',1, 20, 5);
         print '</td>';
	
	print '<td class="liste_titre" align="left"><input class="flat" type="text" size="10" name="search_societe" value="'.dol_escape_htmltag($search_societe).'"></td>';
	print '<td class="liste_titre" align="right"><input class="flat" type="text" size="8" name="search_montant_ht" value="'.dol_escape_htmltag($search_montant_ht).'"></td>';
	//print '<td class="liste_titre">&nbsp;</td>';
	//print '<td class="liste_titre" align="right"><input class="flat" type="text" size="8" name="search_montant_ttc" value="'.dol_escape_htmltag($search_montant_ttc).'"></td>';
	print '<td class="liste_titre">&nbsp;</td>';
	//print '<td class="liste_titre">&nbsp;</td>';
	print '<td class="liste_titre" align="right">';
	print '<input type="image" class="liste_titre" name="button_search" src="'.img_picto($langs->trans("Search"),'search.png','','',1).'" value="'.dol_escape_htmltag($langs->trans("Search")).'" title="'.dol_escape_htmltag($langs->trans("Search")).'">';
	print '</td>';
	print '<td class="liste_titre" align="center">';
	if ($conf->use_javascript_ajax) print '<a href="#" id="checkall">'.$langs->trans("All").'</a> / <a href="#" id="checknone">'.$langs->trans("None").'</a>';
	print '</td>';
	print "</tr>\n";

	if ($num > 0)
	{
		$var=True;
		$total_ht=0;
		$total_tva=0;
		$total_ttc=0;
		$total_paid=0;

		$facturestatic=new Facture($db);

		while ($i < $num)
		{
			$objp = $db->fetch_object($resql);
			$date_limit=$db->jdate($objp->datelimite);

			$var=!$var;

			print "<tr ".$bc[$var].">";
			$classname = "impayee";

			print '<td class="nowrap">';

			$facturestatic->id=$objp->facid;
			$facturestatic->ref=$objp->facnumber;
			$facturestatic->type=$objp->type;

			print '<table class="nobordernopadding"><tr class="nocellnopadd">';

			// Ref
			print '<td class="nobordernopadding nowrap">';
			print $facturestatic->getNomUrl(1);
			print '</td>';

			// Warning picto
			print '<td width="20" class="nobordernopadding nowrap">';
			if ($date_limit < ($now - $conf->facture->client->warning_delay) && ! $objp->paye && $objp->fk_statut == 1) print img_warning($langs->trans("Late"));
			print '</td>';

			// PDF Picto
			print '<td width="16" align="right" class="nobordernopadding hideonsmartphone">';
            $filename=dol_sanitizeFileName($objp->facnumber);
			$filedir=$conf->facture->dir_output . '/' . dol_sanitizeFileName($objp->facnumber);
			print $formfile->getDocumentsLink($facturestatic->element, $filename, $filedir);
            print '</td>';

			print '</tr></table>';

			print "</td>\n";

			print '<td class="nowrap" align="center">'.dol_print_date($db->jdate($objp->df),'day').'</td>'."\n";
			print '<td class="nowrap" align="center">'.dol_print_date($db->jdate($objp->datelimite),'day').'</td>'."\n";

			print '<td><a href="'.DOL_URL_ROOT.'/comm/fiche.php?socid='.$objp->socid.'">'.img_object($langs->trans("ShowCompany"),"company").' '.dol_trunc($objp->nom,28).'</a></td>';

			print '<td align="right">'.price($objp->total_ht).'</td>';
			
			//print '<td align="right">'.price($objp->total_tva);
			//$tx1=price2num($objp->localtax1);
			//$tx2=price2num($objp->localtax2);
			//$revenuestamp=price2num($objp->revenuestamp);
			//if (! empty($tx1) || ! empty($tx2) || ! empty($revenuestamp)) print '+'.price($tx1 + $tx2 + $revenuestamp);
			//print '</td>';
			//print '<td align="right">'.price($objp->total_ttc).'</td>';
			//print '<td align="right">';
			//$cn=$facturestatic->getSumCreditNotesUsed();
			//if (! empty($objp->am)) print price($objp->am);
			//if (! empty($objp->am) && ! empty($cn)) print '+';
			//if (! empty($cn)) print price($cn);
			//print '</td>';

			// Remain to receive
			print '<td align="right">'.((! empty($objp->am) || ! empty($cn))?price($objp->total_ttc-$objp->am-$cn):'&nbsp;').'</td>';

			// Status of invoice
			print '<td align="right" class="nowrap">';
			print $facturestatic->LibStatut($objp->paye,$objp->fk_statut,5,$objp->am);
			print '</td>';

			// Checkbox
			print '<td align="center">';
			if (! empty($formfile->numoffiles))
				print '<input id="cb'.$objp->facid.'" class="flat checkformerge" type="checkbox" name="toGenerate[]" value="'.$objp->facid.'">';
			else
				print '&nbsp;';
			print '</td>' ;

			print "</tr>\n";
			$total_ht+=$objp->total_ht;
			$total_tva+=($objp->total_tva + $tx1 + $tx2 + $revenuestamp);
			$total_ttc+=$objp->total_ttc;
			$total_paid+=$objp->am + $cn;

			$i++;
		}

		print '<tr class="liste_total">';
		print '<td colspan="4" align="left">'.$langs->trans("Total").'</td>';
		print '<td align="right"><b>'.price($total_ht).'</b></td>';
		//print '<td align="right"><b>'.price($total_tva).'</b></td>';
		//print '<td align="right"><b>'.price($total_ttc).'</b></td>';
		//print '<td align="right"><b>'.price($total_paid).'</b></td>';
		print '<td align="right"><b>'.price($total_ttc - $total_paid).'</b></td>';
		print '<td align="center">&nbsp;</td>';
		print '<td align="center">&nbsp;</td>';
		print "</tr>\n";
	}

	print "</table>";

	/*
	 * Show list of available documents
	 */
	$filedir=$diroutputpdf;
	$genallowed=$user->rights->facture->lire;
	$delallowed=$user->rights->facture->lire;

	print '<br>';
	print '<input type="hidden" name="option" value="'.$option.'">';
	// We disable multilang because we concat already existing pdf.
	$formfile->show_documents('unpaid','',$filedir,$urlsource,$genallowed,$delallowed,'',1,1,0,48,1,$param,$langs->trans("PDFMerge"),$langs->trans("PDFMerge"));
	print '</form>';

	$db->free($resql);
}
else dol_print_error($db,'');


llxFooter();
$db->close();
?>
